@@ -1,10 +1,15 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
-from efl.evas import Rectangle, Line, Text, Polygon
+import os
+from efl.evas import Rectangle, Line, Text, Polygon, FilledImage, \
+    EVAS_IMAGE_ORIENT_180
 from efl import elementary
 from efl.elementary.window import StandardWindow
 
+img_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), "images")
+ic_file = os.path.join(img_path, "logo.png")
+
 def events_cb1(rect, event_name):
     print(event_name + " No data for event")
 
@@ -33,15 +38,17 @@ def core_evas_objects_clicked(obj, item=None):
     poly.point_add(20,30)
     poly.show()
 
+    image = FilledImage(win.evas, file=ic_file, size=(50,70), pos=(120,70))
+    image.orient = EVAS_IMAGE_ORIENT_180
+    image.show()
+
     win.resize(320, 320)
     win.show()
 
 
 if __name__ == "__main__":
-    elementary.init()
 
     core_evas_objects_clicked(None)
 
     elementary.run()
-    elementary.shutdown()
 
