@@ -3,7 +3,8 @@
 
 import os
 
-from efl.evas import EVAS_HINT_EXPAND, EVAS_HINT_FILL
+from efl.evas import EVAS_HINT_EXPAND, EVAS_HINT_FILL, \
+    EXPAND_BOTH, FILL_BOTH, EXPAND_HORIZ, FILL_HORIZ
 from efl import elementary
 from efl import edje
 from efl.elementary.window import StandardWindow
@@ -25,10 +26,6 @@ from efl.elementary.object import ELM_FOCUS_DOWN, ELM_FOCUS_UP
 from efl.elementary.configuration import Configuration
 from efl.elementary.theme import theme_overlay_add
 
-EXPAND_BOTH = EVAS_HINT_EXPAND, EVAS_HINT_EXPAND
-EXPAND_HORIZ = EVAS_HINT_EXPAND, 0.0
-FILL_BOTH = EVAS_HINT_FILL, EVAS_HINT_FILL
-FILL_HORIZ = EVAS_HINT_FILL, 0.5
 
 script_path = os.path.dirname(os.path.abspath(__file__))
 edj_file = os.path.join(script_path, "test.edj")
@@ -557,7 +554,6 @@ def focus5_clicked(obj, item=None):
 
 
 if __name__ == "__main__":
-    elementary.init()
     win = StandardWindow("test", "python-elementary test application",
         size=(320,520))
     win.callback_delete_request_add(lambda o: elementary.exit())
@@ -593,4 +589,3 @@ if __name__ == "__main__":
 
     win.show()
     elementary.run()
-    elementary.shutdown()
